@@ -19,14 +19,15 @@ from ._config import (
     get_run_validators,
     set_run_validators,
 )
+from . import exceptions
 from . import filters
 from . import validators
 
 
-__version__ = "16.0.0"
+__version__ = "16.1.0"
 
 __title__ = "attrs"
-__description__ = "Attributes without boilerplate."
+__description__ = "Attributes Without Boilerplate"
 __uri__ = "https://attrs.readthedocs.io/"
 
 __author__ = "Hynek Schlawack"
@@ -36,8 +37,8 @@ __license__ = "MIT"
 __copyright__ = "Copyright (c) 2015 Hynek Schlawack"
 
 
-s = attributes
-attr = ib = attr
+s = attrs = attributes
+ib = attrib = attr
 
 __all__ = [
     "Attribute",
@@ -46,7 +47,10 @@ __all__ = [
     "asdict",
     "assoc",
     "attr",
+    "attrib",
     "attributes",
+    "attrs",
+    "exceptions",
     "fields",
     "filters",
     "get_run_validators",
